@@ -3,8 +3,11 @@
 import os
 import argparse
 import asyncio
+import grp
 import logging
+import pwd
 import signal
+import sys
 from functools import partial
 
 from .asdnotify import AsyncSystemdNotifier
@@ -26,12 +29,18 @@ def parse_args():
                         help="config file location",
                         metavar="FILE",
                         default=defaults.CONFIG_LOCATION)
+    parser.add_argument("-g", "--group",
+                        help="change eGID to this group")
     parser.add_argument("-l", "--logfile",
                         help="log file location",
                         metavar="FILE")
     parser.add_argument("--disable-uvloop",
                         help="do not use uvloop even if it is available",
                         action="store_true")
+    parser.add_argument("-p", "--pidfile",
+                        help="name of the file to write the current pid to")
+    parser.add_argument("-u", "--user",
+                        help="change eUID to this user")
 
     return parser.parse_args()
 
@@ -49,7 +58,7 @@ def exit_handler(exit_event, signum, frame):  # pragma: no cover pylint: disable
 async def heartbeat():
     """ Hacky coroutine which keeps event loop spinning with some interval
     even if no events are coming. This is required to handle Futures and
-    Events state change when no events are occuring."""
+    Events state change when no events are occurring."""
     while True:
         await asyncio.sleep(.5)
 
@@ -96,8 +105,24 @@ async def amain(cfg, loop):  # pragma: no cover
 
 
 def main():  # pragma: no cover
-    # Parse command line arguments and setup basic logging
     args = parse_args()
+    if args.pidfile is not None:
+        with open(args.pidfile, 'w', encoding='ascii') as pid_file:
+            pid_file.write(str(os.getpid()))
+    if args.group is not None:
+        try:
+            group = grp.getgrnam(args.group)
+            os.setegid(group.gr_gid)
+        except Exception as exc:
+            print("Unable to change eGID to '{}': {}".format(args.group, exc), file=sys.stderr)
+            return os.EX_OSERR
+    if args.user is not None:
+        try:
+            passwd = pwd.getpwnam(args.user)
+            os.seteuid(passwd.pw_uid)
+        except Exception as exc:
+            print("Unable to change eUID to '{}': {}".format(args.user, exc), file=sys.stderr)
+            return os.EX_OSERR
     with utils.AsyncLoggingHandler(args.logfile) as log_handler:
         logger = utils.setup_logger('MAIN', args.verbosity, log_handler)
         utils.setup_logger('STS', args.verbosity, log_handler)
@@ -123,3 +148,4 @@ def main():  # pragma: no cover
         evloop.run_until_complete(amain(cfg, evloop))
         evloop.close()
         logger.info("Server finished its work.")
+    return os.EX_OK
